@@ -21,14 +21,21 @@ from django.conf import settings
 
 # FIXME: 看 Iuno 該怎麼設定
 STATIC_DIR = None
-
-if hasattr(settings, "STATIC_ROOT"):
-    STATIC_DIR = settings.STATIC_ROOT
-
+if not settings.DEBUG:
+    if hasattr(settings, "STATIC_ROOT"):
+        STATIC_DIR = settings.STATIC_ROOT
+else:
+    if hasattr(settings, "STATICFILES_DIRS"):
+        STATIC_DIR = settings.STATICFILES_DIRS[0]
+        
 if not STATIC_DIR:
     STATIC_DIR = os.path.join(settings.BASE_DIR, "static")
 
-TEMPLATE_DIR = settings.TEMPLATES[0]['DIRS'][0]
+TEMPLATE_DIR = None
+if hasattr(settings, "TEMPLATES"):
+    TEMPLATE_DIR = settings.TEMPLATES[0]['DIRS'][0]
+else:
+    TEMPLATE_DIR = os.path.join(settings.BASE_DIR, "templates")
 
 BACKUP_DIR_NAME = "_Iuno.template_editor_backup" 
 
@@ -36,4 +43,4 @@ BACKUP_FILE_DIR = os.path.join(
     STATIC_DIR, BACKUP_DIR_NAME)
 
 if not os.path.isdir(BACKUP_FILE_DIR):
-    os.mkdir(BACKUP_FILE_DIR)
+    os.mkdir(BACKUP_FILE_DIR)
\ No newline at end of file
