@@ -22,7 +22,7 @@ from django.core.management.base import BaseCommand
 
 from Iuno.template_editor.models import Static, Template, FOLDER, FILE
 
-from Iuno.template_editor import TEMPLATE_DIR, STATIC_DIR
+from Iuno.template_editor import TEMPLATE_DIR, STATIC_DIR, BACKUP_FILE_DIR
 
 class Command(BaseCommand):
 
@@ -55,6 +55,9 @@ class Command(BaseCommand):
         for f in os.listdir(path):
             filePath = os.path.join(path, f)
 
+            if filePath.startswith(BACKUP_FILE_DIR):
+                continue
+
             if dirs:
                 create = False
                 for dirName in dirs:
